#### rscript scatterTime.R PosMean.txt

### ファイル名 (PosMean.txt) をデータフレームに入れて，ファイルを読み込む
args <- commandArgs()  # パラメータのベクトル
data.file <- args[6]       # ６番めの要素が最初のパラメータ
d <- read.table(data.file, header = T)
d.act <- d[42 <= d$node & d$node <= 50,]
d.sar <- d[51 <= d$node,]
d.oth <- d[d$node <= 41,]

### スクリーンアウト
cat("inputFile: ")         
cat(data.file)             
cat("\n")                  


##### Main program ####

### デバイスの用意
## アウトファイル・データフレームの作成
image.file <- paste(data.file, ".pdf", sep = "") 
pdf(image.file) 


### プロット
# 枠の作成
plot(d[[2]], d[[3]], type="n", main = "Mean comparison", xlim = range(d[2]), ylim =  range(d[3]))  

## node number をプロットする場合
text(d.act[[2]], d.act[[3]], label=d.act[[1]], cex = 0.7, col='blue')
text(d.sar[[2]], d.sar[[3]], label=d.sar[[1]], cex = 0.7, col='red')
text(d.oth[[2]], d.oth[[3]], label=d.oth[[1]], cex = 0.7, col='black')

## 点でプロットする場合
#par(new = T)
#plot(d.act[[2]], d.act[[3]], pch = 20, xlab = '', ylab = '', xlim = range(d[2]), ylim =  range(d[3]), col='blue')
#par(new = T)
#plot(d.sar[[2]], d.sar[[3]], pch = 20, xlab = '', ylab = '', xlim = range(d[2]), ylim =  range(d[3]), col='red')
#par(new = T)
#plot(d.oth[[2]], d.oth[[3]], pch = 20, xlab = '', ylab = '', xlim = range(d[2]), ylim =  range(d[3]), col='black')


### 原点を通る回帰直線の傾きを求めて，図に回帰曲線を引く
lf <- glm(d[[3]] ~ d[[2]] - 1)     #  モデルのあてはめ結果を lf にしまう．
cf <- lf$coefficients
curve(x + 0,to = max(d[[2]]), add= T)
eq <- sprintf('y = %.3fx',cf[1])


### 重相関係数を求める
c.result <- cor.test(d[[2]], d[[3]])
r <- c.result$estimate
r2 <- r^2
Rsq <- sprintf("R^2 = %.3f", r2)


## 回帰直線の式を書き込む
#  現在の座標系を取得
par('usr') -> usr                      
#  x軸の，左から 80% のところ．
x <- (usr[1] + usr[2]) * 0.8 + usr[1]  
#  y軸の，下から 20% のところ．
y <- (usr[4] - usr[3]) * 0.2 + usr[3]  
text(x, y, eq)


#　重相関係数を書き込む
y <- (usr[4] - usr[3]) * 0.15 + usr[3]  #  y軸の，下から 15% のところ．
text(x, y, Rsq)


## デバイスを閉じる
dev.off() 
